@@ -22,7 +22,7 @@
 
 
 # import logging
-
+import os
 
 class Object(object):
 
@@ -53,6 +53,8 @@ class Object(object):
         :return: True if verbose mode is enable, False for disable it.
         :rtype: bool
         """
+        if 'DD_SYSPASS_CLIENT_VERBOSE' in os.environ and os.environ['DD_SYSPASS_CLIENT_VERBOSE'] is not None:
+            return bool(os.environ['DD_SYSPASS_CLIENT_VERBOSE'])
         return bool(self.__verbose)
 
     @verbose.setter
@@ -88,6 +90,8 @@ class Object(object):
         :return: The debug level as set with MorseDecoder.set_debug_level()
         :rtype: int
         """
+        if 'DD_SYSPASS_CLIENT_VERBOSE_LEVEL' in os.environ and os.environ['DD_SYSPASS_CLIENT_VERBOSE_LEVEL'] is not None:
+            return int(os.environ['DD_SYSPASS_CLIENT_VERBOSE_LEVEL'])
         return self.__verbose_level
 
     @verbose_level.setter
@@ -119,6 +123,8 @@ class Object(object):
         :return: True if debugging mode is enable, False for disable it.
         :rtype: bool
         """
+        if 'DD_SYSPASS_CLIENT_DEBUG' in os.environ and os.environ['DD_SYSPASS_CLIENT_DEBUG'] is not None:
+            return bool(os.environ['DD_SYSPASS_CLIENT_DEBUG'])
         return bool(self.__debug)
 
     @debug.setter
@@ -154,7 +160,9 @@ class Object(object):
         :return: The debug level as set with MorseDecoder.set_debug_level()
         :rtype: int
         """
-        return self.__debug_level
+        if 'DD_SYSPASS_CLIENT_DEBUG_LEVEL' in os.environ and os.environ['DD_SYSPASS_CLIENT_DEBUG_LEVEL'] is not None:
+            return int(os.environ['DD_SYSPASS_CLIENT_DEBUG_LEVEL'])
+        return int(self.__debug_level)
 
     @debug_level.setter
     def debug_level(self, debug_level):
