@@ -102,7 +102,7 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         Make the request ith the 'requests' python module.
 
         :param data: the data it will be convert on json
-        :type data: dict
+        :type data: dict or str
         :param verify: SSL certificate verification
         :type verify: bool
         :return: the request.post return
@@ -757,11 +757,10 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         # look_for_error(data, req)
 
         # We got a response
-        if 'result' in req and 'count' in req['result'] and req['result']['count'] > 0:
+        if 'result' in req and 'count' in req['result'] and req['result']['count'] > 0 and 'result' in req['result']:
             for res in req['result']['result']:
                 if res['name'].upper() == text.upper():
                     return res['id']
-
         else:  # pragma: no cover
             return None
 
@@ -1075,7 +1074,6 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         if 'result' in req and 'count' in req['result'] and req['result']['count'] > 0 and 'result' in req['result']:
             for res in req['result']['result']:
                 if res['name'].upper() == text.upper():
-                    # return req['result']['result'][0]['id']
                     return res['id']
 
         else:  # pragma: no cover
